4 ms·
Yet we got a ~5% speed advantage when I refactored bytecode to wordcode https://bugs.python.org/issue26647 https://bugs.python.org/issue26647
by __s 10y ago
Yet we got a ~5% speed advantage when I refactored bytecode to wordcode https://bugs.python.org/issue26647 https://bugs.python.org/issue26647